<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<!--
******************************************************************
*
* File: prdf2html.xsl
*
* Copyright 2009 Programming Research Ltd
*
* Written: C.Waddingham, 6-August-2009
*
* Purpose: XSL Stylesheet for generating an HTML report.
*
* Usage: Use as input to xsltproc, e.g.:
*        xsltproc prdf2html.xsl pass1.xml >report.xhtml
*
******************************************************************
-->

<!DOCTYPE section [
  <!ENTITY nbsp '&#160;'>
]>

<xsl:stylesheet version="1.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:svg="http://www.w3.org/2000/svg" 
                xmlns:v="urn:schemas-microsoft-com:vml" 
                xmlns:prqa="http://www.programmingresearch.com/todo" >

  <!-- Settings file -->
  <xsl:include href="html_settings.xsl"/>

  <!-- set $html_format true => Generate HTML
                        false => Generate XHTML -->
  <xsl:param name='html_format' select="true()" />
  <xsl:param name='logo_file' />

<!-- HTML: -->
  <xsl:output method="html"
            indent="yes" /> 
  
<!-- XHTML:
  <xsl:output method="xml"
            doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
            doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
            indent="yes" /> 
-->

<!-- Following commented out as cannot find a way to specify the
     location of these files at run-time:
  <xsl:include href='headings_xhtml.xsl'/>
  <xsl:include href='textual_xhtml.xsl'/>
  <xsl:include href='file_list_xhtml.xsl'/>
  <xsl:include href='table_xhtml.xsl'/>
  <xsl:include href='svg_xhtml.xsl'/>
  <xsl:include href='verbatim_xhtml.xsl'/>
  <xsl:include href='hierarchy_graphic_xhtml.xsl'/>
  <xsl:include href='function_structure_diagram_xhtml.xsl'/>
  <xsl:include href='eoln_xhtml.xsl'/>
  <xsl:include href='nbsp_xhtml.xsl'/>
-->

  <xsl:variable name="empty_string"/>

  <xsl:template match="/">
    <html>
      <head>
        <title>
          <xsl:value-of select="/prqa:report/prqa:title"/>
          <xsl:text> : </xsl:text>
          <xsl:value-of select="/prqa:report/prqa:project_name"/>
        </title>
        <style type="text/css">
          .rotate{ direction: ltr; writing-mode: tb-rl }
v\:* { behavior: url(#default#VML); }
        table.prqatable,td,th 
        {
            border-style: <xsl:value-of select="$prqa_table_border_style"/>;
            border-color: <xsl:value-of select="$prqa_table_border_colour"/>;
            border-collapse: <xsl:value-of select="$prqa_table_border_collapse"/>;
            border-width: <xsl:value-of select="$prqa_table_border_width"/>px;
        }
        body
        {
          font-family: <xsl:value-of select="$prqa_body_font"/>;
        }
        </style>
      </head>
      <body>
        <center>
          <xsl:if test="$logo_file">
            <img>
              <xsl:attribute name="src">
                <xsl:value-of select="$logo_file" />
              </xsl:attribute>
              <xsl:attribute name="alt">
                <xsl:text>logo</xsl:text>
              </xsl:attribute>
            </img>
          </xsl:if>
          <br/>
          <xsl:if test="/prqa:report/prqa:title != $empty_string">
            <h1>
              <xsl:value-of select="/prqa:report/prqa:title"/>
            </h1>
          </xsl:if>
          <br/>
          <xsl:if test="/prqa:report/prqa:project_name != $empty_string">
            <h2>
              <xsl:value-of select="/prqa:report/prqa:project_name"/>
            </h2>
          </xsl:if>
          <br/>
          <xsl:if test="/prqa:report/prqa:date != $empty_string">
            <h2>
              <xsl:value-of select="/prqa:report/prqa:date"/>
            </h2>
          </xsl:if>
          <xsl:apply-templates mode="doc" select="/prqa:report/prqa:front_page"/>
          <br/>
          <hr/>
        </center>

<!-- add a target for the link for each title -->
        <h2>Contents</h2>
        <ul>
          <xsl:apply-templates mode="toc" select="/prqa:report/prqa:main"/>
          <xsl:apply-templates mode="toc_app" select="/prqa:report/prqa:appendices"/>
        </ul>
        <hr/>   

        <xsl:apply-templates mode="doc" select="/prqa:report/prqa:main"/>
        <xsl:apply-templates mode="doc_app" select="/prqa:report/prqa:appendices"/>

      </body>
    </html>
  </xsl:template>

  <xsl:template mode="doc" match="prqa:section" >
    <xsl:apply-templates mode="doc"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:section" >
    <xsl:apply-templates mode="doc_app"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:section">
    <xsl:apply-templates mode="toc" select="prqa:h2|prqa:h3|prqa:h4"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:section">
    <xsl:apply-templates mode="toc_app" select="prqa:h2|prqa:h3|prqa:h4"/>
  </xsl:template>

<!--
</xsl:stylesheet>
-->

<!--
******************************************************************
*
* File: headings_xhtml.xsl
*
* Written: C.Waddingham, 6-August-2009
*
* Purpose: XSL Stylesheet included by prdf2html.xsl.
*
******************************************************************

<!DOCTYPE section [
  <!ENTITY nbsp '&#160;'>
]>

<xsl:stylesheet version="1.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:prqa="http://www.programmingresearch.com/todo">
-->

  <xsl:template mode="doc" match="prqa:h2">
    <h2>
      <a name="{generate-id(.)}">
        <xsl:number from="/" level="any" count="prqa:h2"/>
        <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
        <xsl:value-of select="."/>
      </a>
    </h2>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:h2">
    <h2>
      <a name="{generate-id(.)}">
        <xsl:number from="/prqa:report/prqa:appendices" level="any" count="prqa:h2" format="A"/>
        <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
        <xsl:value-of select="."/>
      </a>
    </h2>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:h2">
    <p>
      <xsl:number from="/" level="any" count="prqa:h2"/>
      <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
      <a href="#{generate-id(.)}">
        <xsl:value-of select="."/>
      </a>
    </p>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:h2">
    <p>
      <xsl:number from="/prqa:report/prqa:appendices" level="any" count="prqa:h2" format="A"/>
      <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
      <a href="#{generate-id(.)}">
        <xsl:value-of select="."/>
      </a>
    </p>
  </xsl:template>

  <xsl:template mode="doc" match="prqa:h3">
    <h3>
      <a name="{generate-id(.)}">
        <xsl:number from="/" level="any" count="prqa:h2"/>
        <xsl:text>.</xsl:text>
        <xsl:number from="prqa:h2" level="any" count="prqa:h3"/>
        <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
        <xsl:value-of select="."/>
      </a>
    </h3>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:h3">
    <h3>
      <a name="{generate-id(.)}">
        <xsl:number from="/prqa:report/prqa:appendices" level="any" count="prqa:h2" format="A"/>
        <xsl:text>.</xsl:text>
        <xsl:number from="prqa:h2" level="any" count="prqa:h3"/>
        <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
        <xsl:value-of select="."/>
      </a>
    </h3>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:h3">
    <p>
      <xsl:number from="/" level="any" count="prqa:h2"/>
      <xsl:text>.</xsl:text>
      <xsl:number from="prqa:h2" level="any" count="prqa:h3"/>
      <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
      <a href="#{generate-id(.)}">
        <xsl:value-of select="."/>
      </a>
    </p>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:h3">
    <p>
      <xsl:number from="/prqa:report/prqa:appendices" level="any" count="prqa:h2" format="A"/>
      <xsl:text>.</xsl:text>
      <xsl:number from="prqa:h2" level="any" count="prqa:h3"/>
      <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
      <a href="#{generate-id(.)}">
        <xsl:value-of select="."/>
      </a>
    </p>
  </xsl:template>

  <xsl:template mode="doc" match="prqa:h4">
    <h4>
      <a name="{generate-id(.)}">
        <xsl:number from="/" level="any" count="prqa:h2"/>
        <xsl:text>.</xsl:text>
        <xsl:number from="prqa:h2" level="any" count="prqa:h3"/>
        <xsl:text>.</xsl:text>
        <xsl:number from="prqa:h3" level="any" count="prqa:h4"/>
        <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
        <xsl:value-of select="."/>
      </a>
    </h4>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:h4">
    <h4>
      <a name="{generate-id(.)}">
        <xsl:number from="/prqa:report/prqa:appendices" level="any" count="prqa:h2" format="A"/>
        <xsl:text>.</xsl:text>
        <xsl:number from="prqa:h2" level="any" count="prqa:h3"/>
        <xsl:text>.</xsl:text>
        <xsl:number from="prqa:h3" level="any" count="prqa:h4"/>
        <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
        <xsl:value-of select="."/>
      </a>
    </h4>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:h4">
    <p>
      <xsl:number from="/" level="any" count="prqa:h2"/>
      <xsl:text>.</xsl:text>
      <xsl:number from="prqa:h2" level="any" count="prqa:h3"/>
      <xsl:text>.</xsl:text>
      <xsl:number from="prqa:h3" level="any" count="prqa:h4"/>
      <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
      <a href="#{generate-id(.)}">
<!--
        <xsl:number from="/" level="any" count="prqa:h2|prqa:h3|prqa:h4" format="1.1.1. "/>
-->
        <xsl:value-of select="."/>
      </a>
    </p>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:h4">
    <p>
      <xsl:number from="/prqa:report/prqa:appendices" level="any" count="prqa:h2" format="A"/>
      <xsl:text>.</xsl:text>
      <xsl:number from="prqa:h2" level="any" count="prqa:h3"/>
      <xsl:text>.</xsl:text>
      <xsl:number from="prqa:h3" level="any" count="prqa:h4"/>
      <xsl:text>&nbsp;&nbsp;&nbsp;&nbsp;</xsl:text>
      <a href="#{generate-id(.)}">
        <xsl:value-of select="."/>
      </a>
    </p>
  </xsl:template>

<!--
******************************************************************
*
* File: textual_xhtml.xsl
*
* Written: C.Waddingham, 6-August-2009
*
* Purpose: XSL Stylesheet included by prdf2html.xsl.
*
******************************************************************

<xsl:stylesheet version="1.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:prqa="http://www.programmingresearch.com/todo">
-->

  <xsl:template mode="doc" match="prqa:text">
    <xsl:call-template name="prqa_text"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:text">
    <xsl:call-template name="prqa_text"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:text">
    <xsl:call-template name="prqa_text"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:text">
    <xsl:call-template name="prqa_text"/>
  </xsl:template>

  <xsl:template name="prqa_text">
    <xsl:choose>
      <xsl:when test="@bold='1'">
        <b>
          <xsl:apply-templates mode="doc"/>
        </b>
      </xsl:when>
      <xsl:otherwise> 
        <xsl:apply-templates mode="doc"/>
      </xsl:otherwise> 
    </xsl:choose>
  </xsl:template>

  <!-- -->

  <xsl:template mode="doc" match="prqa:h5">
    <xsl:call-template name="prqa_h5"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:h5">
    <xsl:call-template name="prqa_h5"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:h5">
    <xsl:call-template name="prqa_h5"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:h5">
    <xsl:call-template name="prqa_h5"/>
  </xsl:template>

  <xsl:template name="prqa_h5">
    <h5>
      <xsl:apply-templates/>
    </h5>
  </xsl:template>

  <!-- -->

  <xsl:template mode="doc" match="prqa:subscript">
    <xsl:call-template name="prqa_subscript"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:subscript">
    <xsl:call-template name="prqa_subscript"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:subscript">
    <xsl:call-template name="prqa_subscript"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:subscript">
    <xsl:call-template name="prqa_subscript"/>
  </xsl:template>

  <xsl:template name="prqa_subscript">
    <sub><xsl:apply-templates mode="doc"/></sub>
  </xsl:template>

  <!-- -->

  <xsl:template mode="doc" match="prqa:italic">
    <xsl:call-template name="prqa_italic"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:italic">
    <xsl:call-template name="prqa_italic"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:italic">
    <xsl:call-template name="prqa_italic"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:italic">
    <xsl:call-template name="prqa_italic"/>
  </xsl:template>

  <xsl:template name="prqa_italic">
    <i>
      <xsl:apply-templates mode="doc"/>
    </i>
  </xsl:template>

<!--
******************************************************************
*
* File: file_list_xhtml.xsl
*
* Written: C.Waddingham, 6-August-2009
*
* Purpose: XSL Stylesheet included by prdf2html.xsl.
*
******************************************************************

<xsl:stylesheet version="1.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:prqa="http://www.programmingresearch.com/todo">
-->

  <xsl:template mode="doc" match="prqa:file_list">
    <xsl:call-template name="prqa_file_list"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:file_list">
    <xsl:call-template name="prqa_file_list"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:file_list">
    <xsl:call-template name="prqa_file_list"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:file_list">
    <xsl:call-template name="prqa_file_list"/>
  </xsl:template>

  <xsl:template name="prqa_file_list">
    <ul>
      <xsl:apply-templates select="prqa:filename"/>
    </ul>
  </xsl:template>

  <!-- -->

  <xsl:template match="prqa:filename">
    <li><xsl:apply-templates/></li>
  </xsl:template>

<!--
******************************************************************
*
* File: table_xhtml.xsl
*
* Written: C.Waddingham, 6-August-2009
*
* Purpose: XSL Stylesheet included by prdf2html.xsl.
*
******************************************************************

<xsl:stylesheet version="1.0" 
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:prqa="http://www.programmingresearch.com/todo">
-->

  <xsl:template mode="doc" match="prqa:table">
    <xsl:call-template name="prqa_table"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:table">
    <xsl:call-template name="prqa_table"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:table">
    <xsl:call-template name="prqa_table"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:table">
    <xsl:call-template name="prqa_table"/>
  </xsl:template>

  <xsl:template name="prqa_table">
    <xsl:if test="@formating='1'">
      <hr/>
    </xsl:if>
    <table class="prqatable">
      <xsl:if test="@width">
        <xsl:attribute name="width">
          <xsl:value-of select="@width" />
        </xsl:attribute>
      </xsl:if>
      <xsl:for-each select="prqa:col_width">
        <col>
          <xsl:attribute name="width">
            <xsl:value-of select="@width" />
          </xsl:attribute>
        </col>
      </xsl:for-each>
      <xsl:for-each select="prqa:row">
        <tr>
        <xsl:if test="@valign='1'">
          <xsl:attribute name="valign">
            <xsl:value-of select="'top'" />
          </xsl:attribute>
        </xsl:if>

        <xsl:for-each select="prqa:cell">
          <td>
  
          <xsl:if test="@heading">
            <xsl:choose>
              <xsl:when test="@heading='1'">
                  <xsl:attribute name="bgcolor"><xsl:value-of select="$prqa_table_head1"/></xsl:attribute>
              </xsl:when>
              <xsl:when test="@heading='2'">
                <xsl:attribute name="bgcolor"><xsl:value-of select="$prqa_table_head2"/></xsl:attribute>
              </xsl:when>
            </xsl:choose>
          </xsl:if>
  
          <xsl:if test="string-length(@bgcolor)">
            <xsl:attribute name="bgcolor">
              <xsl:value-of select="@bgcolor" />
            </xsl:attribute>
          </xsl:if>
  
          <xsl:if test="string-length(@colspan)">
            <xsl:attribute name="colspan">
              <xsl:value-of select="@colspan" />
            </xsl:attribute>
          </xsl:if>
  
          <xsl:if test="string-length(@align)">
            <xsl:attribute name="align">
              <xsl:value-of select="@align" />
            </xsl:attribute>
          </xsl:if>
  
          <xsl:if test="string-length(@angle)">
            <xsl:attribute name="class">
              <xsl:text>rotate</xsl:text>
            </xsl:attribute>
          </xsl:if>
  
          <xsl:apply-templates/>
  
          </td>
        </xsl:for-each>
      </tr>
      </xsl:for-each>
    </table>
  </xsl:template>

<!--
******************************************************************
*
* File: svg_xhtml.xsl
*
* Written: C.Waddingham, 6-August-2009
*
* Purpose: XSL Stylesheet included by prdf2html.xsl.
*
******************************************************************

<xsl:stylesheet version="1.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:svg="http://www.w3.org/2000/svg" 
                xmlns:prqa="http://www.programmingresearch.com/todo">
-->

  <xsl:template mode="doc" match="svg:svg">
    <xsl:call-template name="svg_svg"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="svg:svg">
    <xsl:call-template name="svg_svg"/>
  </xsl:template>

  <xsl:template mode="toc" match="svg:svg">
    <xsl:call-template name="svg_svg"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="svg:svg">
    <xsl:call-template name="svg_svg"/>
  </xsl:template>

  <xsl:template name="svg_svg">
    <xsl:if test="not(boolean($html_format))">
      <xsl:copy-of select="."/>
    </xsl:if>
  </xsl:template>

<!--
******************************************************************
*
* File: vml_xhtml.xsl
*
* Written: C.Waddingham, 24-August-2009
*
* Purpose: XSL Stylesheet included by prdf2html.xsl.
*
******************************************************************

<xsl:stylesheet version="1.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:v="urn:schemas-microsoft-com:vml" 
                xmlns:prqa="http://www.programmingresearch.com/todo">
-->

  <xsl:template mode="doc" match="v:group">
    <xsl:call-template name="v_group"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="v:group">
    <xsl:call-template name="v_group"/>
  </xsl:template>

  <xsl:template mode="toc" match="v:group">
    <xsl:call-template name="v_group"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="v:group">
    <xsl:call-template name="v_group"/>
  </xsl:template>

  <xsl:template name="v_group">
    <xsl:if test="boolean($html_format)">
      <xsl:copy-of select="."/>
    </xsl:if>
  </xsl:template>

<!--
******************************************************************
*
* File: verbatim_xhtml.xsl
*
* Written: C.Waddingham, 6-August-2009
*
* Purpose: XSL Stylesheet included by prdf2html.xsl.
*
******************************************************************

<xsl:stylesheet version="1.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:prqa="http://www.programmingresearch.com/todo">
-->

  <xsl:template mode="doc" match="prqa:verbatim">
    <xsl:call-template name="prqa_verbatim"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:verbatim">
    <xsl:call-template name="prqa_verbatim"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:verbatim">
    <xsl:call-template name="prqa_verbatim"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:verbatim">
    <xsl:call-template name="prqa_verbatim"/>
  </xsl:template>

  <xsl:template name="prqa_verbatim">
    <pre><xsl:value-of select="."/></pre>
  </xsl:template>

<!--
******************************************************************
*
* File: hierarchy_graphic_xhtml.xsl
*
* Written: C.Waddingham, 6-August-2009
*
* Purpose: XSL Stylesheet included by prdf2html.xsl.
*
******************************************************************

<xsl:stylesheet version="1.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:svg="http://www.w3.org/2000/svg" 
                xmlns:prqa="http://www.programmingresearch.com/todo">
-->

  <xsl:template mode="doc" match="prqa:hierarchy_graphic">
    <xsl:call-template name="prqa_hierarchy_graphic"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:hierarchy_graphic">
    <xsl:call-template name="prqa_hierarchy_graphic"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:hierarchy_graphic">
    <xsl:call-template name="prqa_hierarchy_graphic"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:hierarchy_graphic">
    <xsl:call-template name="prqa_hierarchy_graphic"/>
  </xsl:template>

  <xsl:template name="prqa_hierarchy_graphic">
    <xsl:if test="@kind">
      <hr/>
      <h4>
      <xsl:value-of select="@kind" />
      </h4>
    </xsl:if>
    <xsl:apply-templates mode="doc"/>
  </xsl:template>

<!--
******************************************************************
*
* File: function_structure_diagram_xhtml.xsl
*
* Written: C.Waddingham, 6-August-2009
*
* Purpose: XSL Stylesheet included by prdf2html.xsl.
*
******************************************************************

<xsl:stylesheet version="1.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:prqa="http://www.programmingresearch.com/todo">
-->

  <xsl:template mode="doc" match="prqa:function_structure_diagram">
    <xsl:call-template name="prqa_function_structure_diagram"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:function_structure_diagram">
    <xsl:call-template name="prqa_function_structure_diagram"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:function_structure_diagram">
    <xsl:call-template name="prqa_function_structure_diagram"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:function_structure_diagram">
    <xsl:call-template name="prqa_function_structure_diagram"/>
  </xsl:template>

  <xsl:template name="prqa_function_structure_diagram">
    <hr/>
    <h4>function structure diagram</h4>
    <xsl:apply-templates mode="doc"/>
  </xsl:template>

<!--
******************************************************************
*
* File: eoln_xhtml.xsl
*
* Written: C.Waddingham, 6-August-2009
*
* Purpose: XSL Stylesheet included by prdf2html.xsl.
*
******************************************************************

<xsl:stylesheet version="1.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:prqa="http://www.programmingresearch.com/todo">
-->

  <xsl:template mode="doc" match="prqa:eoln">
    <xsl:call-template name="prqa_eoln"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:eoln">
    <xsl:call-template name="prqa_eoln"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:eoln">
    <xsl:call-template name="prqa_eoln"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:eoln">
    <xsl:call-template name="prqa_eoln"/>
  </xsl:template>

  <xsl:template name="prqa_eoln">
    <br/>
  </xsl:template>

<!--
******************************************************************
*
* File: nbsp_xhtml.xsl
*
* Written: C.Waddingham, 26-November-2009
*
* Purpose: XSL Stylesheet included by prdf2html.xsl.
*
******************************************************************

<xsl:stylesheet version="1.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:prqa="http://www.programmingresearch.com/todo">
-->

  <xsl:template mode="doc" match="prqa:nbsp">
    <xsl:call-template name="prqa_nbsp"/>
  </xsl:template>

  <xsl:template mode="doc_app" match="prqa:nbsp">
    <xsl:call-template name="prqa_nbsp"/>
  </xsl:template>

  <xsl:template mode="toc" match="prqa:nbsp">
    <xsl:call-template name="prqa_nbsp"/>
  </xsl:template>

  <xsl:template mode="toc_app" match="prqa:nbsp">
    <xsl:call-template name="prqa_nbsp"/>
  </xsl:template>

  <xsl:template name="prqa_nbsp">
    &nbsp;
  </xsl:template>

</xsl:stylesheet>

<!-- 
** eof prdf2html.xsl ******************************************
-->